==> financial-front-2.0.1.tar.gz: financial-front-2.0.1/app/controllers/account_controller.rb <==
# -*- coding: utf-8 -*-

# Netsphere Financial Front / ネットスフィア経理フロント
# Copyright (C) 2007-2009,2011 HORIKAWA Hisashi. All rights reserved.
#     http://www.nslabs.jp/bside/
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


# ユーザ認証
class AccountController < ApplicationController
  # Be sure to include AuthenticationSystem in Application Controller instead
  include AuthenticatedSystem
  # If you want "remember me" functionality, add this before_filter to Application Controller
  before_filter :login_from_cookie
  before_filter :login_required, :only => :edit_pwd
  protect_from_forgery :except => [:authenticate, :get, :count]

  # say something nice, you goof!  something sweet.
  def index
    redirect_to(:action => 'signup') unless logged_in? || User.count > 0
  end

  def login
    return unless request.post?
    self.current_user = User.authenticate(params[:login], params[:password])
    if logged_in?
      if params[:remember_me] == "1"
        self.current_user.remember_me
        cookies[:auth_token] = { :value => self.current_user.remember_token , :expires => self.current_user.remember_token_expires_at }
      end
      redirect_back_or_default(:controller => 'account', :action => 'index')
      flash[:notice] = "ログインに成功しました。"
    else
      @error = "ログインIDまたはパスワードが違います。"
    end
  end

  def signup
    if User.find(:first)
      flash[:notice] = 'すでにユーザが登録されています。'
      redirect_to :controller => 'account', :action => 'index'
      return
    end
      
    @user = User.new params[:user]
    @user.attributes = {
      :active => 1,
      :keiri_flag => true,    # 最初のユーザは経理ロール
      :marketing_flag => false,
      :apar_flag => true,
      :hrd_flag => true,
    }
    return unless request.post?  # 入力フォーム表示

#    User.transaction {
      #role = Role.find_by_keiri(1)
      #raise if !role
=begin
      div = Division.new :name => '経理 (変更してください)', 
                         :kana_name => 'ケイリ',
                         :division_code => 'xxx',
                         # :role_id => role.id,
                         :purchase_active => 1
      div.save!
=end
      @user.save!
=begin
      UsersDivision.create! :user_id => @user.id,
                            :division_id => div.id,
                            :default_pair => 1,
                            :effective_day => Date.today
    }
=end
    self.current_user = @user
    redirect_back_or_default(:controller => '/account', :action => 'index')
    flash[:notice] = "Thanks for signing up!"
  rescue ActiveRecord::RecordInvalid
    render :action => 'signup'
  end
  
  def logout
    self.current_user.forget_me if logged_in?
    cookies.delete :auth_token
    reset_session
    flash[:notice] = "You have been logged out."
    redirect_back_or_default(:controller => '/account', :action => 'index')
  end
  
  # パスワードの編集
  def edit_pwd
  end
  
  def update_pwd
    @worker = current_user
    if @worker.update_attributes(params[:worker])
      flash[:notice] = 'パスワードを変更しました。'
      redirect_to :controller => 'users', :action => 'show', :id => @worker
    else
      render :action => 'edit_pwd'
    end
  end

  # 別システムから認証機能を利用する
  # TODO: もっとまともなのにすること。
  def authenticate
    if request.post? 
      @user = User.authenticate(params[:login], params[:password])
    end
    headers['Content-Type'] = 'application/xml'
    render :action => 'get', :status => (@user ? 200 : 500),  :layout => false
  end
  
  def get
    @user = User.find_by_id params[:id]
    headers['Content-Type'] = 'application/xml'
    render :status => (@user ? 200 : 500),  :layout => false
  end
  
  def count
    @count = User.count
    headers['Content-Type'] = 'application/xml'
    render :status => 200, :layout => false
  end
end

==> financial-front-2.99.0.tar.gz: financial-front-2.99.0/app/controllers/account_controller.rb <==
# -*- coding: utf-8 -*-

# Netsphere Financial Front / ネットスフィア経理フロント
# Copyright (C) 2007-2009,2011 HORIKAWA Hisashi. All rights reserved.
#     http://www.nslabs.jp/bside/
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


# ユーザ認証
class AccountController < ApplicationController
  # Be sure to include AuthenticationSystem in Application Controller instead
  include AuthenticatedSystem
  # If you want "remember me" functionality, add this before_filter to Application Controller
  before_filter :login_from_cookie
  before_filter :login_required, :only => :edit_pwd
  protect_from_forgery :except => [:authenticate, :get, :count]

  # say something nice, you goof!  something sweet.
  def index
    redirect_to(:action => 'signup') unless logged_in? || User.count > 0
  end

  def login
    return unless request.post?
    self.current_user = User.authenticate(params[:login], params[:password])
    if logged_in?
      if params[:remember_me] == "1"
        self.current_user.remember_me
        cookies[:auth_token] = { :value => self.current_user.remember_token , :expires => self.current_user.remember_token_expires_at }
      end

      flash[:notice] = "ログインに成功しました。"
      redirect_back_or_default(:controller => 'welcome', :action => 'index')
    else
      @error = "ログインIDまたはパスワードが違います。"
    end
  end


  def signup
    if User.find(:first)
      flash[:notice] = 'すでにユーザが登録されています。'
      redirect_to :controller => 'account', :action => 'index'
      return
    end
      
    @user = User.new params[:user]
    @user.attributes = {
      :active => 1,
      :keiri_flag => true,    # 最初のユーザは経理ロール
      :marketing_flag => false,
      :apar_flag => true,
      :hrd_flag => true,
    }
    return unless request.post?  # 入力フォーム表示

#    User.transaction {
      #role = Role.find_by_keiri(1)
      #raise if !role
=begin
      div = Division.new :name => '経理 (変更してください)', 
                         :kana_name => 'ケイリ',
                         :division_code => 'xxx',
                         # :role_id => role.id,
                         :purchase_active => 1
      div.save!
=end
      @user.save!
=begin
      UsersDivision.create! :user_id => @user.id,
                            :division_id => div.id,
                            :default_pair => 1,
                            :effective_day => Date.today
    }
=end
    self.current_user = @user
    redirect_back_or_default(:controller => '/account', :action => 'index')
    flash[:notice] = "Thanks for signing up!"
  rescue ActiveRecord::RecordInvalid
    render :action => 'signup'
  end

  
  def logout
    self.current_user.forget_me if logged_in?
    cookies.delete :auth_token
    reset_session
    flash[:notice] = "You have been logged out."
    redirect_back_or_default(:controller => '/welcome', :action => 'index')
  end

  
  # パスワードの編集
  def edit_pwd
  end
  
  def update_pwd
    @worker = current_user
    if @worker.update_attributes(params[:worker])
      flash[:notice] = 'パスワードを変更しました。'
      redirect_to :controller => 'users', :action => 'show', :id => @worker
    else
      render :action => 'edit_pwd'
    end
  end


  # 別システムから認証機能を利用する
  # TODO: もっとまともなのにすること。
  def authenticate
    if request.post? 
      @user = User.authenticate(params[:login], params[:password])
    end
    headers['Content-Type'] = 'application/xml'
    render :action => 'get', :status => (@user ? 200 : 500),  :layout => false
  end
  
  def get
    @user = User.find_by_id params[:id]
    headers['Content-Type'] = 'application/xml'
    render :status => (@user ? 200 : 500),  :layout => false
  end
  
  def count
    @count = User.count
    headers['Content-Type'] = 'application/xml'
    render :status => 200, :layout => false
  end
end
